=======
History
=======

0.1.2 (2016-08-29)
------------------
* Added get_all_account_info to AdwordsUtility
* Added date_range to utils

0.1.1 (2016-08-29)
------------------
* Download report as GZIPPED_CSV, then unzip and load locally.

0.1.0 (2016-08-26)
------------------

* First release on PyPI.
